@@ -204,7 +204,7 @@ class ChannelTypeRoomList(Channel, _ChannelTypeRoomListIface):
         self._listing_rooms = False
         self._rooms = {}
 
-        self._add_immutables(self, {'Server': CHANNEL_TYPE_ROOM_LIST})
+        self._add_immutables({'Server': CHANNEL_TYPE_ROOM_LIST})
 
     @dbus.service.method(CHANNEL_TYPE_ROOM_LIST, in_signature='', out_signature='b')
     def GetListingRooms(self):
@@ -294,7 +294,10 @@ class ChannelTypeText(Channel, _ChannelTypeTextIface):
 
     @dbus.service.signal(CHANNEL_TYPE_TEXT, signature='uuuuus')
     def Received(self, id, timestamp, sender, type, flags, text):
-        self._pending_messages[id] = (timestamp, sender, type, flags, text)
+        if id in self._pending_messages:
+            raise ValueError("You can't receive the same message twice.")
+        else:
+            self._pending_messages[id] = (timestamp, sender, type, flags, text)
 
 
 from telepathy._generated.Channel_Interface_Chat_State \
