@@ -91,8 +91,11 @@ class Connection(_Connection, DBusProperties):
         self._interfaces = set()
 
         DBusProperties.__init__(self)
-        self._implement_property_get(CONN_INTERFACE,
-                {'SelfHandle': lambda: dbus.UInt32(self.GetSelfHandle())})
+        self._implement_property_get(CONN_INTERFACE, {
+                'SelfHandle': lambda: dbus.UInt32(self.GetSelfHandle()),
+                'Interfaces': lambda: dbus.Array(self.GetInterfaces(), signature='s'),
+                'Status': lambda: dbus.UInt32(self.GetStatus())
+                 })
 
         self._proto = proto
 
@@ -450,9 +453,9 @@ class ConnectionInterfaceRequests(
         target_id = props.get(CHANNEL_INTERFACE + '.TargetID', None)
 
         # Handle type 0 cannot have a handle.
-        if target_handle_type == HANDLE_TYPE_NONE and target_handle != None:
+        if target_handle_type == HANDLE_TYPE_NONE and target_handle not in (None, 0):
             raise InvalidArgument('When TargetHandleType is NONE, ' +
-                'TargetHandle must be omitted')
+                'TargetHandle must be omitted or 0')
 
         # Handle type 0 cannot have a TargetID.
         if target_handle_type == HANDLE_TYPE_NONE and target_id != None:
